import { 
    select, 
    csv, 
    scaleLinear, 
  	scaleTime, 
    extent, 
  	area,
  	curveBasis,
    axisLeft,
    axisBottom,

} from 'd3'

const svg = select('svg')
const height = +svg.attr('height');//parseFloat
const width = +svg.attr('width');
const title = 'temperature in San';

//d.mpg = +d.mpg;
//d.cylinders = +d.cylinders;
//d.displacement = +d.displacement;
//d.horsepower = +d.horsepower;
//d.weight = +d.weight;
//d.acceleration = +d.acceleration;
//d.year = +d.year;

const render = data=> {
    const xValue = d => d.timestamp;
  	const XAxislabel = 'Time';
    const yValue = d => d.temperature;
  	const YAxislabel = 'temperature';
  	
  	const Radius = 5;
    const margin={top: 50, right: 40, bottom: 75, left: 150};
    const innerwidth= width-margin.left-margin.right;
    const innerheight= height-margin.top-margin.bottom;

    const xScale = scaleTime()
      	.domain(extent(data, xValue))
        .range([0, innerwidth])

    const yScale = scaleLinear()
        .domain(extent(data, yValue))
        .range([innerheight,0])
  			.nice();

//the margin convention
    const g = svg.append('g')
        .attr('transform', `translate(${margin.left},${margin.top})`);
//  const xAxisTickFormat = number => 
//    	format('.3s')(number)
//   		.replace('G','B');
  
  	const xAxis = axisBottom(xScale)
    		.ticks(6)
    		.tickSize(-innerheight)
    		//.tickFormat(xAxisTickFormat)
  			.tickPadding(15);
  
  	const yAxis = axisLeft(yScale)
    		.tickSize(-innerwidth)
    		.tickPadding(10);
    //adding axis
   	const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();//remove unnecessary lines
  	//selectAll can choose more than one thing comparing with the select
  			
 	 	yAxisG.append('text')
  		.attr('class','axis-label')
  		.attr('y',-90)
  		.attr('x',-innerheight / 2)
  		.attr('fill','black')
  		.attr('transform', `rotate(-90)`)
  		.attr('text-anchor','middle')
  		.text(YAxislabel);
  
    const xAxisG = g.append('g').call(xAxis)
        .attr('transform', `translate(0,${innerheight})`);
  	xAxisG.select('.domain').remove();
  	xAxisG.append('text')
  		.attr('class','axis-label')
  		.attr('y',65)
  		.attr('x',innerwidth/2)
  		.attr('fill','black')
  		.text(XAxislabel);
  
  	const areaG = area()
    	.x(d=> xScale(xValue(d)))
    	.y0(innerheight)
    	.y1(d=> yScale(yValue(d)))
    	.curve(curveBasis);
  
  	g.append('path')
  		.attr('class', 'area-label')
  		.attr('d',areaG(data));

  	g.append('text')
  		.attr('class','title-label')
  		.attr('y', -10)
  		.text(title);
};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
	.then(data => {
  	console.log(data)
    data.forEach(d => {
      d.temperature = +d.temperature;
			d.timestamp = new Date(d.timestamp);
    });
    render(data);
  })